@@ -26,7 +26,7 @@
   */
 
 class PanelsGroup : public TQObject  {
-Q_OBJECT
+TQ_OBJECT
 public:
 
  PanelsGroup(TQWidget *widget, TQObject *parent=0, const char *name=0) {};
